import { useLocation, useParams } from 'react-router-dom'
import { ModForm } from '../components/ModForm'
import { ProfileSection } from '../components/ProfileSection'
import '../styles/innerPage.css'
import '../styles/styles.css'
import '../styles/write.css'
import { Filter, nip19 } from 'nostr-tools'
import { RelayController } from '../controllers'
import { extractModData, log, LogType } from '../utils'
import { ModDetails } from '../types'
import { toast } from 'react-toastify'
import { useState } from 'react'
import { LoadingSpinner } from '../components/LoadingSpinner'
import { useDidMount } from '../hooks'

export const SubmitModPage = () => {
  const location = useLocation()
  const { nevent } = useParams()
  const [modData, setModData] = useState<ModDetails>()
  const [isFetching, setIsFetching] = useState(false)

  const title = location.pathname.startsWith('/edit-mod')
    ? 'Edit Mod'
    : 'Submit a mod'

  useDidMount(async () => {
    if (nevent) {
      const decoded = nip19.decode<'nevent'>(nevent as `nevent1${string}`)
      const eventId = decoded.data.id
      const kind = decoded.data.kind
      const author = decoded.data.author
      const relays = decoded.data.relays || []

      const filter: Filter = {
        ids: [eventId]
      }

      if (kind) filter.kinds = [kind]

      if (author) filter.authors = [author]

      setIsFetching(true)
      RelayController.getInstance()
        .fetchEvent(filter, relays)
        .then((event) => {
          if (event) {
            const extracted = extractModData(event)
            setModData(extracted)
          }
        })
        .catch((err) => {
          log(
            true,
            LogType.Error,
            'An error occurred in fetching mod details from relays',
            err
          )
          toast.error('An error occurred in fetching mod details from relays')
        })
        .finally(() => {
          setIsFetching(false)
        })
    }
  })
  return (
    <div className='InnerBodyMain'>
      <div className='ContainerMain'>
        <div className='IBMSecMainGroup IBMSecMainGroupAlt'>
          <div className='IBMSMSplitMain'>
            <div className='IBMSMSplitMainBigSide'>
              <div className='IBMSMTitleMain'>
                <h2 className='IBMSMTitleMainHeading'>{title}</h2>
              </div>
              <div className='IBMSMSMBS_Write'>
                {isFetching ? (
                  <LoadingSpinner desc='Fetching mod details from relays' />
                ) : (
                  <ModForm existingModData={modData} />
                )}
              </div>
            </div>
            <ProfileSection />
          </div>
        </div>
      </div>
    </div>
  )
}
